<template>
  <GasBillRechargeStep1 v-if="current === 'step1'" />
  <GasBillRechargeStep2 v-else-if="current === 'step2'" />
  <GasBillRechargeStep3
    v-else-if="current === 'step3'"
    v-bind="props"
    @go-pay="emit('goPay', $event)"
  />
</template>

<script setup lang="ts">
import { computed, provide, reactive } from 'vue';
import { useStepper } from 'senin-mini/hooks';
import { GasBillRechargeContextKey } from './context';
import GasBillRechargeStep1 from './GasBillRechargeStep1.vue';
import GasBillRechargeStep2 from './GasBillRechargeStep2.vue';
import GasBillRechargeStep3 from './GasBillRechargeStep3.vue';
import { LifeRechargeConstants } from '@life-payment/core-vue';

defineOptions({
  name: 'GasBillRecharge',
});

type Props = {
  isDev?: boolean;
};

const props = withDefaults(defineProps<Props>(), {
  isDev: false,
});

const stepperInfo = useStepper(['step1', 'step2', 'step3'], 'step3');
const current = computed(() => stepperInfo.current.value);

const emit = defineEmits<{
  (e: 'goPay', orderNo: string): void;
}>();

const preSetForm = reactive({
  gasOrgType: '' as any as LifeRechargeConstants.GasOrgCodeEnum,
  province: '',
  city: '',
  gasAccount: '',
  remark: '',
});

provide(GasBillRechargeContextKey, {
  ...stepperInfo,
  preSetForm,
});
</script>
